#
# spec file for package python3-pyflakes
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-pyflakes
Version:        0.9.2
Release:        6.1
Url:            https://github.com/pyflakes/pyflakes
Summary:        Passive checker of Python 3 programs
License:        MIT
Group:          Development/Languages/Python
Source:         https://pypi.python.org/packages/source/p/pyflakes/pyflakes-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# please do not remove, needed for openSUSE <= 12.2
BuildRequires:  python3
BuildRequires:  python3-2to3
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
# please do not remove, needed for openSUSE <= 12.2
Requires:       python3
BuildArch:      noarch

%description
Pyflakes is program to analyze Python programs and detect various errors. It
works by parsing the source file, not importing it, so it is safe to use on
modules with side effects. It's also much faster.

%prep
%setup -q -n pyflakes-%{version}

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
mv %{buildroot}%{_bindir}/pyflakes %{buildroot}%{_bindir}/pyflakes-python%{py3_ver}

%files
%defattr(-,root,root,-)
%doc LICENSE NEWS.txt README.rst AUTHORS
%{_bindir}/pyflakes-python%{py3_ver}
%{python3_sitelib}/pyflakes/
%{python3_sitelib}/pyflakes-%{version}-py*.egg-info

%changelog
* Thu Jun 18 2015 arun@gmx.de
- update to version 0.9.2:
  * Fix a traceback when a global is defined in one scope, and used in
    another.
* Tue Jun 16 2015 arun@gmx.de
- update to version 0.9.1:
  * Update NEWS.txt to include 0.9.0, which had been forgotten.
* Sun May 31 2015 arun@gmx.de
- specfile:
  * fixed pypi location
* Sun May 31 2015 arun@gmx.de
- specfile:
  * updated url
  * updated source location to pypi
- updated to version 0.9.0:
  * Exit gracefully, not with a traceback, on SIGINT and SIGPIPE.
  * Fix incorrect report of undefined name when using lambda
    expressions in generator expressions.
  * Don't crash on DOS line endings on Windows and Python 2.6.
  * Don't report an undefined name if the 'del' which caused a name to
    become undefined is only conditionally executed.
  * Properly handle differences in list comprehension scope in Python
    3.
  * Improve handling of edge cases around 'global' defined variables.
  * Report an error for 'return' outside a function.
* Fri Apr 11 2014 toddrme2178@gmail.com
- Update to 0.8.1:
  - Detect the declared encoding in Python 3.
  - Do not report redefinition of import in a local scope, if the
    global name is used elsewhere in the module.
  - Catch undefined variable in loop generator when it is also used as
    loop variable.
  - Report undefined name for `(a, b) = (1, 2)` but not for the general
    unpacking `(a, b) = func()`.
  - Correctly detect when an imported module is used in default arguments
    of a method, when the method and the module use the same name.
  - Distribute a universal wheel file.
- Update to 0.8.0:
  - Adapt for the AST in Python 3.4.
  - Fix caret position on SyntaxError.
  - Fix crash on Python 2.x with some doctest SyntaxError.
  - Add tox.ini.
  - The `PYFLAKES_NODOCTEST` environment variable has been replaced with the
    `PYFLAKES_DOCTEST` environment variable (with the opposite meaning).
    Doctest checking is now disabled by default; set the environment variable
    to enable it.
  - Correctly parse incremental `__all__ += [...]`.
  - Catch return with arguments inside a generator (Python <= 3.2).
  - Do not complain about `_` in doctests.
  - Drop deprecated methods `pushFunctionScope` and `pushClassScope`.
* Tue Nov 19 2013 dmueller@suse.com
- install LICENSE (and other usual boilerplate)
* Wed Jul  3 2013 dmueller@suse.com
- update to 0.7.3:
  - Do not report undefined name for generator expression and dict or
    set comprehension at class level.
  - Deprecate `Checker.pushFunctionScope` and `Checker.pushClassScope`:
    use `Checker.pushScope` instead.
  - Remove dependency on Unittest2 for the tests.
* Mon Apr 22 2013 toddrme2178@gmail.com
- Re-add buildrequires: python3.  This is needed for openSUSE <= 12.2
* Sun Apr 21 2013 dmueller@suse.com
- update to 0.7:
  - Add --version and --help options.
  - Support `python -m pyflakes` (Python 2.7 and Python 3.x).
  - Add attribute `Message.col` to report column offset.
  - Do not report redefinition of variable for a variable used in a list
    comprehension in a conditional.
  - Do not report redefinition of variable for generator expressions and
    set or dict comprehensions.
  - Do not report undefined name when the code is protected with a
    `NameError` exception handler.
  - Do not report redefinition of variable when unassigning a module imported
    for its side-effect.
  - Support special locals like `__tracebackhide__` for py.test.
  - Support checking doctests.
  - Fix issue with Turkish locale where `'i'.upper() == 'i'` in Python 2.
  - Fix detection of variables in augmented assignments.
  - Support Python 3 up to 3.3, based on the pyflakes3k project.
  - Preserve compatibility with Python 2.5 and all recent versions of Python.
  - Support custom reporters in addition to the default Reporter.
  - Allow function redefinition for modern property construction via
    property.setter/deleter.
  - Fix spurious redefinition warnings in conditionals.
  - Do not report undefined name in __all__ if import * is used.
  - Add WindowsError as a known built-in name on all platforms.
  - Support specifying additional built-ins in the `Checker` constructor.
  - Don't issue Unused Variable warning when using locals() in current scope.
  - Handle problems with the encoding of source files.
  - Remove dependency on Twisted for the tests.
  - Support `python setup.py test` and `python setup.py develop`.
  - Create script using setuptools `entry_points` to support all platforms,
* Thu Nov 22 2012 toddrme2178@gmail.com
- Removed openSUSE 11.4 spec file workarounds
* Fri Apr 27 2012 toddrme2178@gmail.com
- Fix building python 3 package on openSUSE 11.4 x86_64
* Thu Apr 26 2012 toddrme2178@gmail.com
- Add python 3 package
